@@ -386,8 +386,7 @@ Returns this row's primary key.
 
 sub Id  {
     my $pkey = $_[0]->_PrimaryKey();
-    my $ret = $_[0]->{'values'}->{$pkey};
-    return $ret;
+    return $_[0]->{'values'}->{ $pkey };
 }
 
 
@@ -404,7 +403,7 @@ Return a hash of the values of our primary keys for this function.
 
 sub PrimaryKeys { 
     my $self = shift; 
-    return map { $_ => $self->{'values'}->{$_} } @{$self->_PrimaryKeys};
+    return map { $_ => $self->{'values'}->{lc $_} } @{$self->_PrimaryKeys};
 }
 
 
@@ -703,7 +702,7 @@ sub __Value {
     my $self = shift;
     my $field = lc shift;
 
-    $field = $self->_Accessible($field, "column") if $self->_Accessible($field, "column");
+    $field = $self->_Accessible($field, "column") || $field;
 
     return $self->{'values'}{$field} if $self->{'fetched'}{$field};
     $self->{'fetched'}{$field} = 1;
@@ -1209,7 +1208,7 @@ sub _LoadFromSQL {
 
     #TODO this only gets the first row. we should check if there are more.
 
-    return ( 0, "Couldn't execute query" ) unless $sth;
+    return ( 0, "Couldn't execute query: ".$self->_Handle->dbh->errstr ) unless $sth;
 
     $self->{'values'} = $sth->fetchrow_hashref;
     $self->{'fetched'} = {};
